# Changelog of: python-wipbox

## v0

### v0.0.8

- Try CI/CD publishing process.
- Improve `setup.py`

### v0.0.7 

- Version alignement.

### v0.0.3

- Version alignment.

### v0.0.2

- Initial version, partially tested.
